import 'package:flutter/material.dart';

class CommonImage extends StatelessWidget {

  final String image;
  final String fallbackImage;
  final BoxFit fit;
  final String semanticLabel;
  final double height;
  final double width;

  const CommonImage({
    Key key,
    @required this.image,
    @required this.fallbackImage,
    this.fit,
    this.semanticLabel,
    this.height,
    this.width,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Image(
      height: height,
      width: width,
      semanticLabel: semanticLabel,
      fit: fit,
      image: image != null
        ? _getAssetOrNetworkImage(image)
        : _getAssetOrNetworkImage(fallbackImage),
    );
  }

  ImageProvider _getAssetOrNetworkImage(String url) {
    if(url.startsWith('http')){
      return NetworkImage(url);
    }
    return AssetImage(url);
  }
}
