import 'package:flutter/material.dart';

class CommonPageLoader extends StatefulWidget {
  final bool isLoading;
  final Widget child;
  final String img;
  final String text;
  final double opacity;
  final Color color;

  CommonPageLoader({
    @required this.isLoading,
    @required this.child,
    this.img,
    this.text,
    this.opacity = 0.8,
    this.color = Colors.black54,
  });

  @override
  _CommonPageLoaderState createState() => _CommonPageLoaderState();
}

class _CommonPageLoaderState extends State<CommonPageLoader> with SingleTickerProviderStateMixin {
  AnimationController _controller;
  Animation<double> _animation;
  bool _overlayVisible;

  _CommonPageLoaderState();

  @override
  void initState() {
    super.initState();
    _overlayVisible = false;
    _controller = AnimationController(vsync: this, duration: Duration(milliseconds: 300));
    _animation = Tween(begin: 0.0, end: 1.0).animate(_controller);
    _animation.addStatusListener((status) {
      if(status == AnimationStatus.forward) {
        setState(() => { _overlayVisible = true });
      }
      if(status == AnimationStatus.dismissed) {
        setState(() => { _overlayVisible = false });
      }
    });
    if (widget.isLoading) {
      _controller.forward();
    }
  }

  @override
  void didUpdateWidget(CommonPageLoader oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (!oldWidget.isLoading && widget.isLoading) {
      _controller.forward();
    }

    if (oldWidget.isLoading && !widget.isLoading) {
      _controller.reverse();
    }
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final List<Widget> widgets = <Widget>[];
    widgets.add(widget.child);

    if (_overlayVisible == true) {
      final modal = FadeTransition(
        opacity: _animation,
        child: Stack(
          children: <Widget>[
            Opacity(
              opacity: widget.opacity,
              child: ModalBarrier(
                dismissible: false,
                color: widget.color,
              ),
            ),
            Center(child: _loaderIndicator()),
          ],
        ),
      );
      widgets.add(modal);
    }
    return Stack(children: widgets);
  }

  Widget _loaderIndicator() {
    return Container(
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: <Widget>[
          Image.asset(widget.img,
            height: 60.0,
            width: 60.0,
          ),
          Text(widget.text,
            style: Theme.of(context).textTheme.headline4.copyWith(color: Colors.white)
          )
        ],
      ),
    );
  }
}