import 'package:flutter/material.dart';
import 'package:vegigo2_ui_common/theme/colors.dart';
import 'package:vegigo2_ui_common/util/size_config.dart';
part 'custom_fab_option.dart';

class CustomFab extends StatefulWidget {
  final List<CustomFabOption> fabOptions;
  final Icon icon;
  final double radius;
  final double fabHeight;
  final double fabWidth;
  final Color backgroundColor;

  const CustomFab({
    Key key,
    @required this.fabOptions,
    this.icon = const Icon(Icons.add),
    @required this.radius,
    this.fabHeight = 200,
    this.fabWidth = 200,
    @required this.backgroundColor,
  }) : super(key: key);

  @override
  _CustomFabState createState() => _CustomFabState();
}

class _CustomFabState extends State<CustomFab> with SingleTickerProviderStateMixin {
  bool showOptions = false;
  AnimationController _animationController;
  final double _fabHeight = 15.0;
  Animation<double> _translateButton;

  @override
  void initState() {
    super.initState();
    _animationController = AnimationController(vsync: this, duration: Duration(milliseconds: 500))
      ..addListener(() {
        /*
        * setState() is required to show the FabOptions with updated value.
        * value is updated by Tween (animation).
        */
        setState(() {});
      });
    _translateButton = Tween<double>(begin: _fabHeight, end: -10).animate(
      CurvedAnimation(
        parent: _animationController,
        curve: Interval(0.0, 0.75),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.end,
      crossAxisAlignment: CrossAxisAlignment.end,
      children: [
        if (showOptions)
          Container(
            height: widget.fabHeight * SizeConfig.heightMultiplier,
            width: widget.fabWidth * SizeConfig.widthMultiplier,
            child: ListView.builder(
              itemCount: widget.fabOptions.length,
              physics: NeverScrollableScrollPhysics(),
              reverse: true,
              itemBuilder: (context, index) {
                return Transform(
                  transform: Matrix4.translationValues(0, _translateButton.value * (index + 1), 0),
                  child: widget.fabOptions[index],
                );
              },
            ),
          ),
        Container(
          width: 2 * widget.radius * SizeConfig.textMultiplier,
          child: FittedBox(
            child: FloatingActionButton(
              onPressed: () {
                setState(() {
                  showOptions = !showOptions;
                });
                showOptions ? _animationController.forward() : _animationController.reverse();
              },
              backgroundColor: widget.backgroundColor,
              child: widget.icon,
            ),
          ),
        ),
      ],
    );
  }
}
