import 'package:flutter/material.dart';
import 'package:vegigo2_ui_common/util/constants.dart';

enum OrderStatus {
  RECEIVED,
  IN_PROGRESS,
  OUT_FOR_DELIVERY,
  DELIVERED,
  CANCELLED
}

extension OrderStatusExtension on OrderStatus {
  static const values = {
    OrderStatus.RECEIVED: 'RECEIVED',
    OrderStatus.IN_PROGRESS: 'IN_PROGRESS',
    OrderStatus.OUT_FOR_DELIVERY: 'OUT_FOR_DELIVERY',
    OrderStatus.DELIVERED: 'DELIVERED',
    OrderStatus.CANCELLED: 'CANCELLED'
  };

  static Map<OrderStatus, OrderStatusDisplay>  displayFactory = {
    OrderStatus.RECEIVED: OrderStatusDisplay(
      message: Constants.RECEIVED,
      icon: Icons.access_time,
      color: Colors.deepOrangeAccent
    ),
    OrderStatus.IN_PROGRESS: OrderStatusDisplay(
      message: Constants.IN_PROGRESS,
      icon: Icons.access_time,
      color: Colors.deepOrangeAccent
    ),
    OrderStatus.OUT_FOR_DELIVERY: OrderStatusDisplay(
      message: Constants.OUT_FOR_DELIVERY,
      icon: Icons.access_time,
      color: Colors.deepOrangeAccent
    ),
    OrderStatus.DELIVERED: OrderStatusDisplay(
      message: Constants.DELIVERED,
      icon: Icons.check_circle,
    ),
    OrderStatus.CANCELLED: OrderStatusDisplay(
      message: Constants.CANCELLED,
      icon: Icons.cancel,
      color: Colors.red
    ),
  };

  String get value => values[this];
  OrderStatusDisplay get display => displayFactory[this];
}

extension OrderStatusParser on String {
  OrderStatus toOrderStatus() {
    return OrderStatus.values.firstWhere(
      (type) => type.toString().toLowerCase().split('.').last == toLowerCase(),
      orElse: () => null
    ); //return null if not found
  }
}

class OrderStatusDisplay {
  String message;
  IconData icon;
  Color color;

  OrderStatusDisplay({
    @required this.message,
    @required this.icon,
    this.color = Colors.green
  });
}