import 'package:meta/meta.dart';
import 'package:vegigo2_ui_common/entities/product/unit.dart';
import 'package:vegigo2_ui_common/entities/product/unit_price_mapping.dart';
import 'package:vegigo2_ui_common/models/product/unit_model.dart';

class UnitPriceMappingModel extends UnitPriceMapping {
  UnitPriceMappingModel({
    @required String id,
    @required Unit unit,
    @required double magnitude,
    @required double price,
    @required int maxQuantity,
    @required double savings,
    @required double discountedPrice,
    bool isDefault = false
  }) : super( 
    id: id,
    unit: unit,
    magnitude: magnitude,
    price: price,
    maxQuantity: maxQuantity,
    savings: savings,
    discountedPrice: discountedPrice,
    isDefault: isDefault
  );

  factory UnitPriceMappingModel.fromJson(Map<String, dynamic> json) =>
    UnitPriceMappingModel(
      id: json['id'].toString(),
      unit: UnitModel.fromJson(json['unit'] as Map<String, dynamic>),
      magnitude: double.parse(json['magnitude'].toString()),
      price: double.parse(json['price'].toString()),
      maxQuantity: json['maxQuantity'] as int,
      savings: double.parse(json['savings'].toString()),
      discountedPrice: double.parse(json['discountedPrice'].toString()),
      isDefault: json['default'] as bool
    );

  Map<String, dynamic> toJson() => {
    'id': id,
    'unit': (unit as UnitModel).toJson(),
    'magnitude': magnitude,
    'price': price,
    'maxQuantity': maxQuantity,
    'savings': savings,
    'discountedPrice': discountedPrice
  };

  static List<UnitPriceMappingModel> fromJsonArray(List<dynamic> jsonArray) {
    return jsonArray.map((jsonUnitPriceMapping) => UnitPriceMappingModel.fromJson(
      jsonUnitPriceMapping as Map<String, dynamic>)
    ).toList();
  }

  static List<Map<String, dynamic>> toJsonArray(List<UnitPriceMappingModel> unitPriceMappings) {
    return unitPriceMappings.map((UnitPriceMappingModel unitPriceMapping) => unitPriceMapping.toJson()).toList();
  }
}