import 'package:flutter/material.dart';
import 'package:vegigo2_ui_common/theme/colors.dart' as colors;
import 'package:vegigo2_ui_common/util/constants.dart';
import 'package:vegigo2_ui_common/vegigo2_ui_common.dart';

class OrderBillingInfo extends StatelessWidget {
  final double itemsTotal;
  final double offerDiscount;
  final double grandTotal;
  final double totalSavings;
  final List<String> offers;
  final Color labelColor;

  OrderBillingInfo({
    @required this.itemsTotal,
    @required this.offerDiscount,
    @required this.grandTotal,
    @required this.totalSavings,
    @required this.offers,
    this.labelColor = colors.DARK_GREY_2,
  });

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        _billingItem(
          context,
          text1: Constants.TOTAL_PRICE,
          text2: '${Constants.RUPEE_ICON_LABEL}${itemsTotal}',
          style: Theme.of(context).textTheme.headline5.copyWith(
            color: labelColor,
            fontSize: 13 * SizeConfig.textMultiplier,
          ),
        ),
        SizedBox(height: 3.0 * SizeConfig.heightMultiplier,),
        MediaQuery.removePadding(
          removeTop: true,
          context: context,
          child: ListView.builder(
            physics: NeverScrollableScrollPhysics(),
            shrinkWrap: true,
            itemCount: offers.length,
            itemBuilder: (BuildContext context, int index) {
              return _billingItem(context,
                text1: '${Constants.OFFER_LABEL}${offers[index]}',
                text2: '- ${Constants.RUPEE_ICON_LABEL}${offerDiscount}',
                style: Theme.of(context).textTheme.headline5.copyWith(
                  fontSize: 13 * SizeConfig.textMultiplier,
                  color: colors.DARK_GREEN,
                  fontWeight: FontWeight.bold
                ),
              );
            },
          ),
        ),
        SizedBox(height: 3.0 * SizeConfig.heightMultiplier),
        _billingItem(context,
          text1: Constants.DELIVERY_CHARGES,
          text2: '${Constants.RUPEE_ICON_LABEL}${0.0}', // TODO: Delivery Charge
          style: Theme.of(context).textTheme.headline5.copyWith(
            color: labelColor,
            fontSize: 13 * SizeConfig.textMultiplier,
          ),
        ),
        Padding(
          padding: EdgeInsets.symmetric(vertical: 5.0 * SizeConfig.heightMultiplier),
          child: Divider(height: 1.0, color: labelColor,),
        ),
        _billingItem(context,
          text1: Constants.GRAND_TOTAL,
          text2: '${Constants.RUPEE_ICON_LABEL}${grandTotal}',
          style: Theme.of(context).textTheme.headline5.copyWith(
            color: labelColor,
            fontSize: 15 * SizeConfig.textMultiplier,
            fontWeight: FontWeight.bold,
          ),
        ),
        SizedBox(height: 2.0 * SizeConfig.heightMultiplier),
        _orderSavings(context)
      ],
    );
  }

  Widget _billingItem(BuildContext context, {String text1, String text2, TextStyle style}) {
    return Padding(
      padding: EdgeInsets.symmetric(
        vertical: 3.0 * SizeConfig.heightMultiplier, 
        horizontal: 5.0 * SizeConfig.widthMultiplier
      ),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: <Widget>[
          Text(text1, style: style),
          Text(text2, style: style)
        ],
      ),
    );
  }

  Widget _orderSavings(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(vertical: 3.0 * SizeConfig.heightMultiplier),
      decoration: BoxDecoration(
        color: Colors.green.shade50,
        border: Border.all(color: Colors.green),
        borderRadius: BorderRadius.all(Radius.circular(8.0)),
      ),
      child: _billingItem(
        context,
        text1: Constants.TOTAL_SAVINGS,
        text2: '${Constants.RUPEE_ICON_LABEL}${totalSavings}',
        style: Theme.of(context).textTheme.headline5.copyWith(
          color: Colors.green,
          fontSize: 13 * SizeConfig.textMultiplier,
        ),
      ),
    );
  }
}
