import 'package:flutter/material.dart';
import 'package:vegigo2_ui_common/widgets/price_per_quantity.dart';
import 'package:vegigo2_ui_common/theme/colors.dart' as colors;
import 'package:vegigo2_ui_common/util/constants.dart';
import 'package:vegigo2_ui_common/vegigo2_ui_common.dart';

class OrderDetailProductsListing extends StatelessWidget {
  final List<OrderProduct> products;

  OrderDetailProductsListing({@required this.products});

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(
        vertical: 10 * SizeConfig.heightMultiplier,
        horizontal: 15 * SizeConfig.widthMultiplier
      ),
      decoration: BoxDecoration(
        color: colors.GREY.withOpacity(0.23),
        borderRadius: BorderRadius.all(Radius.circular(13.0))
      ),
      child: MediaQuery.removePadding(
        removeTop: true,
        context: context,
        child: ListView.builder(
          physics: NeverScrollableScrollPhysics(),
          shrinkWrap: true,
          itemCount: products.length,
          itemBuilder: (BuildContext context, int index) => _orderProductCard(context, product: products[index])
        ),
      ),
    );
  }

  Widget _orderProductCard(BuildContext context, {OrderProduct product}) {
    return Container(
      padding: EdgeInsets.symmetric(
        horizontal: 12.0 * SizeConfig.widthMultiplier, 
        vertical: 10.0 * SizeConfig.heightMultiplier
      ),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Padding(
            padding: EdgeInsets.only(bottom: 4.0),
            child: Text(
              product.title,
              style: Theme.of(context).textTheme.headline5.copyWith(
                fontWeight: FontWeight.bold,
                color: Colors.black,
                fontSize: 16 * SizeConfig.textMultiplier,
              ),
            ),
          ),
          _pricePerUnitAndQuantity(product, context)
        ],
      ),
    );
  }

  Widget _pricePerUnitAndQuantity(OrderProduct product, BuildContext context) {
    final PricePerQuantity pricePerQuantity =  PricePerQuantity(
      unitPrice: product.unitPriceMapping.discountedPrice,
      unit: product.unitPriceMapping.unit,
      unitAmount: product.unitPriceMapping.magnitude,
      quantity: product.quantity,
    );

    final double totalProductPrice = product.quantity * product.unitPriceMapping.discountedPrice;

    return Row(
      children: <Widget>[
        Expanded(
          flex: 3,
          child: pricePerQuantity.pricePerUnitDisplay(context)
        ),
        Expanded(
          child: pricePerQuantity.quantityDisplay(context)
        ),
        Expanded(
          child: FittedBox(
            fit: BoxFit.none,
            alignment: Alignment.centerLeft,
            child: Text(
              '${Constants.RUPEE_ICON_LABEL}${totalProductPrice.toStringAsFixed(1)}',
              style: Theme.of(context).textTheme.headline4.copyWith(
                color: Colors.black,
                fontSize: 18 * SizeConfig.textMultiplier,
              ),
            ),
          ),
        ),
      ],
    );
  }
}
