import 'package:flutter/material.dart';
import 'package:vegigo2_ui_common/theme/colors.dart' as colors;
import 'package:vegigo2_ui_common/util/constants.dart';
import 'package:vegigo2_ui_common/vegigo2_ui_common.dart';

class PricePerQuantity extends StatelessWidget {
  final double unitPrice;
  final Unit unit;
  final double unitAmount;
  final int quantity;
  final Color priceDisplayColor;

  PricePerQuantity({
    @required this.unitPrice,
    @required this.unit,
    @required this.unitAmount,
    @required this.quantity,
    this.priceDisplayColor = colors.PALE_ORANGE,
  });

  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        pricePerUnitDisplay(context),
        SizedBox(width: 6.0 * SizeConfig.widthMultiplier),
        quantityDisplay(context)
      ],
    );
  }

  Widget pricePerUnitDisplay(BuildContext context) {
    return Row(
      children: <Widget>[
        Text(
          '${Constants.RUPEE_ICON_LABEL}$unitPrice',
          style: Theme.of(context).textTheme.headline5.copyWith(
            color: priceDisplayColor,
            fontSize: 13 * SizeConfig.heightMultiplier,
            fontWeight: FontWeight.bold
          ),
        ),
        SizedBox(width: 5 * SizeConfig.widthMultiplier,),
        Text(
          Constants.QUANTITY_PER_TEXT,
          style: Theme.of(context).textTheme.bodyText2.copyWith(
            color: Colors.black,
            fontSize: 12 * SizeConfig.textMultiplier,
          )
        ),
        Text(
          ' $unitAmount ${unit.abbr}',
          style: Theme.of(context).textTheme.bodyText2.copyWith(
            color: Colors.black,
            fontSize: 12 * SizeConfig.textMultiplier,
          )
        )
      ],
    );
  }

  Widget quantityDisplay(BuildContext context) {
    return Text(
      '${Constants.MULTIPLE_SYMBOL}$quantity',
      style: Theme.of(context).textTheme.headline5.copyWith(
        color: colors.DARK_GREEN,
        fontWeight: FontWeight.bold
      ),
    );
  }
}
