import 'package:flutter/material.dart';
import 'package:vegigo2_ui_common/core/common_image.dart';
import 'package:vegigo2_ui_common/theme/colors.dart' as colors;
import 'package:vegigo2_ui_common/util/constants.dart';
import 'package:vegigo2_ui_common/util/images.dart' as images;

class ProductThumbnail extends StatelessWidget {
  final String thumbnail;
  final double discountRatio;
  final double borderRadius;
  final double imageSize;

  ProductThumbnail({
    @required this.thumbnail,
    @required this.discountRatio,
    this.borderRadius = 0.0,
    this.imageSize = 90.0,
  });

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: <Widget>[
        Padding(
          padding: const EdgeInsets.only(left: 6.0),
          child: CommonImage(
            image: thumbnail,
            fallbackImage: images.PRODUCT_DEFAULT,
            semanticLabel: 'item',
            fit: BoxFit.contain,
            width: imageSize,
            height: imageSize,
          ),
        ),
        if (discountRatio > 0)
          Positioned(
            top: 0,
            left: 0,
            child: Container(
              padding: EdgeInsets.symmetric(horizontal: 6.0, vertical: 3.0),
              decoration: BoxDecoration(
                color: colors.DARK_GREEN,
                borderRadius: BorderRadius.only(
                    topRight: Radius.circular(8.0),
                    bottomLeft: Radius.circular(8.0),
                    bottomRight: Radius.circular(borderRadius)),
              ),
              child: Text('${discountRatio * 100}${Constants.PAGE_DISCOUNT_LABEL}',
                  style: Theme.of(context).textTheme.subtitle2.copyWith(fontSize: 11.0, color: Colors.white)),
            ),
          ),
      ],
    );
  }
}
